tracker r1694 - in branches/indexer-split: . src/libtracker src/libtracker-common src/tracker-applet src/tracker-indexer src/trackerd
- From: mr svn gnome org
- To: svn-commits-list gnome org
- Subject: tracker r1694 - in branches/indexer-split: . src/libtracker src/libtracker-common src/tracker-applet src/tracker-indexer src/trackerd
- Date: Tue, 17 Jun 2008 10:58:27 +0000 (UTC)
Author: mr
Date: Tue Jun 17 10:58:27 2008
New Revision: 1694
URL: http://svn.gnome.org/viewvc/tracker?rev=1694&view=rev
Log:
* src/libtracker-common/tracker-hal.c:
* src/libtracker-common/tracker-log.c:
* src/libtracker-common/tracker-nfs-lock.c:
* src/libtracker/tracker-files.c:
* src/libtracker/tracker-get-meta-for-folder.c:
* src/libtracker/tracker-query.c:
* src/tracker-applet/tracker-applet.c:
* src/tracker-indexer/tracker-main.c:
* src/trackerd/tracker-main.c: Changed all locations to use
"initialize" and "finalize" instead of the en_GB version for
consistency.
Modified:
branches/indexer-split/ChangeLog
branches/indexer-split/src/libtracker-common/tracker-hal.c
branches/indexer-split/src/libtracker-common/tracker-log.c
branches/indexer-split/src/libtracker-common/tracker-nfs-lock.c
branches/indexer-split/src/libtracker/tracker-files.c
branches/indexer-split/src/libtracker/tracker-get-meta-for-folder.c
branches/indexer-split/src/libtracker/tracker-query.c
branches/indexer-split/src/tracker-applet/tracker-applet.c
branches/indexer-split/src/tracker-indexer/tracker-main.c
branches/indexer-split/src/trackerd/tracker-main.c
Modified: branches/indexer-split/src/libtracker-common/tracker-hal.c
==============================================================================
--- branches/indexer-split/src/libtracker-common/tracker-hal.c (original)
+++ branches/indexer-split/src/libtracker-common/tracker-hal.c Tue Jun 17 10:58:27 2008
@@ -195,11 +195,11 @@
if (!libhal_ctx_init (priv->context, &error)) {
if (dbus_error_is_set (&error)) {
- g_critical ("Could not initialise the HAL context, %s",
+ g_critical ("Could not initialize the HAL context, %s",
error.message);
dbus_error_free (&error);
} else {
- g_critical ("Could not initialise the HAL context, "
+ g_critical ("Could not initialize the HAL context, "
"no error, is hald running?");
}
Modified: branches/indexer-split/src/libtracker-common/tracker-log.c
==============================================================================
--- branches/indexer-split/src/libtracker-common/tracker-log.c (original)
+++ branches/indexer-split/src/libtracker-common/tracker-log.c Tue Jun 17 10:58:27 2008
@@ -146,6 +146,6 @@
g_free (log->filename);
g_free (log);
- /* Reset the log pointer so we can re-initialise if we want */
+ /* Reset the log pointer so we can re-initialize if we want */
log = NULL;
}
Modified: branches/indexer-split/src/libtracker-common/tracker-nfs-lock.c
==============================================================================
--- branches/indexer-split/src/libtracker-common/tracker-nfs-lock.c (original)
+++ branches/indexer-split/src/libtracker-common/tracker-nfs-lock.c Tue Jun 17 10:58:27 2008
@@ -79,7 +79,7 @@
}
if (!is_initialized()) {
- g_critical ("Could not initialise NFS lock");
+ g_critical ("Could not initialize NFS lock");
return FALSE;
}
@@ -135,7 +135,7 @@
}
if (!is_initialized ()) {
- g_critical ("Could not initialise NFS lock");
+ g_critical ("Could not initialize NFS lock");
return;
}
@@ -172,7 +172,7 @@
NULL);
}
- g_message ("NFS lock initialised %s",
+ g_message ("NFS lock initialized %s",
use_nfs_safe_locking ? "" : "(safe locking not in use)");
}
@@ -193,5 +193,5 @@
tmp_dir = NULL;
}
- g_message ("NFS lock finalised");
+ g_message ("NFS lock finalized");
}
Modified: branches/indexer-split/src/libtracker/tracker-files.c
==============================================================================
--- branches/indexer-split/src/libtracker/tracker-files.c (original)
+++ branches/indexer-split/src/libtracker/tracker-files.c Tue Jun 17 10:58:27 2008
@@ -47,7 +47,7 @@
client = tracker_connect (FALSE);
if (!client) {
- g_print ("Could not initialise Tracker - exiting...\n");
+ g_print ("Could not initialize Tracker - exiting...\n");
return 1;
}
Modified: branches/indexer-split/src/libtracker/tracker-get-meta-for-folder.c
==============================================================================
--- branches/indexer-split/src/libtracker/tracker-get-meta-for-folder.c (original)
+++ branches/indexer-split/src/libtracker/tracker-get-meta-for-folder.c Tue Jun 17 10:58:27 2008
@@ -67,7 +67,7 @@
client = tracker_connect (FALSE);
if (!client) {
- g_print ("Could not initialise Tracker - exiting...\n");
+ g_print ("Could not initialize Tracker - exiting...\n");
return 1;
}
Modified: branches/indexer-split/src/libtracker/tracker-query.c
==============================================================================
--- branches/indexer-split/src/libtracker/tracker-query.c (original)
+++ branches/indexer-split/src/libtracker/tracker-query.c Tue Jun 17 10:58:27 2008
@@ -162,7 +162,7 @@
client = tracker_connect (FALSE);
if (!client) {
- g_print ("Could not initialise Tracker over dbus connection - exiting...\n");
+ g_print ("Could not initialize Tracker over dbus connection - exiting...\n");
return 1;
}
Modified: branches/indexer-split/src/tracker-applet/tracker-applet.c
==============================================================================
--- branches/indexer-split/src/tracker-applet/tracker-applet.c (original)
+++ branches/indexer-split/src/tracker-applet/tracker-applet.c Tue Jun 17 10:58:27 2008
@@ -1675,7 +1675,7 @@
priv->tracker = tracker_connect (FALSE);
if (!priv->tracker) {
- g_print ("Could not initialise Tracker\n");
+ g_print ("Could not initialize Tracker\n");
exit (1);
}
Modified: branches/indexer-split/src/tracker-indexer/tracker-main.c
==============================================================================
--- branches/indexer-split/src/tracker-indexer/tracker-main.c (original)
+++ branches/indexer-split/src/tracker-indexer/tracker-main.c Tue Jun 17 10:58:27 2008
@@ -106,7 +106,7 @@
}
static void
-initialise_signal_handler (void)
+initialize_signal_handler (void)
{
#ifndef OS_WIN32
struct sigaction act;
@@ -226,9 +226,9 @@
g_print ("\n" ABOUT "\n" LICENSE "\n");
g_print ("Initializing tracker-indexer...\n");
- initialise_signal_handler ();
+ initialize_signal_handler ();
- /* Initialise logging */
+ /* Initialize logging */
config = tracker_config_new ();
if (verbosity > -1) {
Modified: branches/indexer-split/src/trackerd/tracker-main.c
==============================================================================
--- branches/indexer-split/src/trackerd/tracker-main.c (original)
+++ branches/indexer-split/src/trackerd/tracker-main.c Tue Jun 17 10:58:27 2008
@@ -422,7 +422,7 @@
}
static void
-initialise_signal_handler (void)
+initialize_signal_handler (void)
{
#ifndef OS_WIN32
struct sigaction act;
@@ -446,7 +446,7 @@
}
static void
-initialise_locations (void)
+initialize_locations (void)
{
gchar *filename;
@@ -472,7 +472,7 @@
}
static void
-initialise_directories (gboolean *need_index)
+initialize_directories (gboolean *need_index)
{
gchar *filename;
@@ -516,7 +516,7 @@
}
static void
-initialise_databases (gboolean need_index)
+initialize_databases (gboolean need_index)
{
Indexer *index;
gchar *final_index_name;
@@ -753,7 +753,7 @@
g_print ("\n" ABOUT "\n" LICENSE "\n");
g_print ("Initializing trackerd...\n");
- initialise_signal_handler ();
+ initialize_signal_handler ();
/* Create struct */
tracker = g_new0 (Tracker, 1);
@@ -763,13 +763,13 @@
/* This makes sure we have all the locations like the data
* dir, user data dir, etc all configured.
*
* The initialise_directories() function makes sure everything
* exists physically and/or is reset depending on various
* options (like if we reindex, we remove the data dir).
*/
- initialise_locations ();
+ initialize_locations ();
- /* Initialise major subsystems */
+ /* Initialize major subsystems */
tracker->config = tracker_config_new ();
tracker->language = tracker_language_new (tracker->config);
@@ -808,7 +808,7 @@
tracker_config_set_verbosity (tracker->config, verbosity);
}
/* Initialise other subsystems */
tracker_log_init (log_filename, tracker_config_get_verbosity (tracker->config));
g_print ("Starting log:\n File:'%s'\n", log_filename);
@@ -822,7 +822,7 @@
sanity_check_option_values ();
- initialise_directories (&need_index);
+ initialize_directories (&need_index);
tracker_nfs_lock_init (tracker_config_get_nfs_locking (tracker->config));
tracker_ontology_init ();
@@ -844,7 +844,7 @@
tracker->readonly = check_multiple_instances ();
- initialise_databases (need_index);
+ initialize_databases (need_index);
/* Set our status as running, if this is FALSE, threads stop
* doing what they do and shutdown.
[
@@ -763,13 +763,13 @@
* dir, user data dir, etc all configured.
*
- * The initialise_directories() function makes sure everything
+ * The initialize_directories() function makes sure everything
* exists physically and/or is reset depending on various
* options (like if we reindex, we remove the data dir).
@@ -808,7 +808,7 @@
tracker_config_set_verbosity (tracker->config, verbosity);
}
- /* Initialise other subsystems */
+ /* Initialize other subsystems */
tracker_log_init (log_filename, tracker_config_get_verbosity (tracker->config));
g_print ("Starting log:\n File:'%s'\n", log_filename);
Date Prev][
Date Next] [
Thread Prev][
Thread Next]
[
Thread Index]
[
Date Index]
[
Author Index]